@@ -1,4 +1,4 @@
-/* $Id: align.h,v 1.10 2004/06/01 16:54:18 c4chris Exp $
+/* $Id: align.h,v 1.11 2008/03/29 01:26:45 c4chris Exp $
  *
  * Christian Iseli, LICR ITO, Christian.Iseli@licr.org
  *
@@ -12,7 +12,7 @@ extern void align_path(uchar *,uchar *,int,int,int,int,int,edit_script_p_t*,
 extern int  align_get_dist(uchar *,uchar *,int, int, int, int, int);
 extern void Condense_both_Ends(edit_script_p_t *, edit_script_p_t *,
 			       edit_script_p_t*);
-extern void S2A(edit_script_p_t, int *, int);
+extern void S2A(edit_script_p_t, int *);
 extern void IDISPLAY(uchar *, uchar *, unsigned int, unsigned int, int *,
 		     unsigned int, unsigned int, collec_p_t, int);
 extern void Free_script(edit_script_p_t);
