@@ -1,4 +1,4 @@
-/* $Id: sim4.h,v 1.56 2008/03/31 22:58:27 c4chris Exp $
+/* $Id: sim4.h,v 1.57 2009/08/31 11:21:49 c4chris Exp $
  *
  * Christian Iseli, LICR ITO, Christian.Iseli@licr.org
  *
@@ -21,6 +21,7 @@
 #define DEFAULT_K           15
 #define DEFAULT_C           15
 #define DEFAULT_CHIMERA     75
+#define DEFAULT_SPLICE_I_D  2
 #define P                   (.2)
 #define MATCH               1
 #define MISMATCH            (-5)
@@ -165,6 +166,7 @@ typedef struct _options_t {
   unsigned int minScore_cutoff;
   unsigned int splitScorePct;
   unsigned int huntChimera;
+  unsigned int spliceInDel;
 } options_t;
 extern options_t options;
 extern char *argv0;
