@@ -1,16 +1,14 @@
-/* $Id: sim4.init.c,v 1.85 2008/04/16 14:32:48 c4chris Exp $
+/* $Id: sim4.init.c,v 1.91 2010/01/11 17:19:15 c4chris Exp $
  *
  * Christian Iseli, LICR ITO, Christian.Iseli@licr.org
  *
- * Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008
+ * Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2010
  * Swiss Institute of Bioinformatics.
  * Copyright (C) 1998-2001  Liliana Florea.
  */
 
 /*
  * TODO
- *  - See why tst23 is split
- *  - See why tst50 has strange alignment
  */
 
 /*
@@ -68,7 +66,7 @@ static void free_seq(seq_p_t);
 
 static const char Usage[] =
 "%s [options] dna est_db\n\n"
-"This is SIBsim4 version 0.17.\n\n"
+"This is SIBsim4 version 0.20.\n\n"
 #ifdef DEBUG
 "Debug version\n\n"
 #endif
@@ -103,6 +101,8 @@ static const char Usage[] =
 "             2: search both strands and report the best match\n"
 "            [%d]\n"
 "  -r <int>  reward for a nucleotide match [%d]\n"
+"  -S <int>  max number of insertions and/or deletions evaluated on the DNA\n"
+"            strand when determining the best splice site positions [%d]\n"
 "  -s <int>  split score in percent [%d]\n"
 "  -W <int>  word size [%d]\n"
 "  -X <int>  value for terminating word extensions [%d]\n";
@@ -146,8 +146,9 @@ main(int argc, char *argv[])
   options.minScore_cutoff = MATCH_CUTOFF;
   options.splitScorePct = DEFAULT_SPLIT_SCORE;
   options.huntChimera = DEFAULT_CHIMERA;
+  options.spliceInDel = DEFAULT_SPLICE_I_D;
   while (1) {
-    int c = getopt(argc, argv, "A:C:c:E:f:g:H:I:K:L:M:o:q:R:r:s:W:X:");
+    int c = getopt(argc, argv, "A:C:c:E:f:g:H:I:K:L:M:o:q:R:r:S:s:W:X:");
     if (c == -1)
       break;
     switch (c) {
@@ -254,6 +255,9 @@ main(int argc, char *argv[])
     case 'r':
       options.matchScore = atoi(optarg);
       break;
+    case 'S':
+      options.spliceInDel = (unsigned int) atoi(optarg);
+      break;
     case 's':
       options.splitScorePct = (unsigned int) atoi(optarg);
       if (options.splitScorePct > 100)
@@ -292,6 +296,7 @@ main(int argc, char *argv[])
 	    options.mismatchScore,
 	    options.reverse,
 	    options.matchScore,
+	    options.spliceInDel,
 	    options.splitScorePct,
 	    options.W,
 	    options.X);
