@@ -1,4 +1,4 @@
-/* $Id: sim4b1.h,v 1.21 2006/06/19 14:15:27 c4chris Exp $
+/* $Id: sim4b1.h,v 1.22 2008/03/31 22:58:27 c4chris Exp $
  *
  * Christian Iseli, LICR ITO, Christian.Iseli@licr.org
  *
@@ -9,9 +9,6 @@
 #ifndef SIM4B1_H
 #define SIM4B1_H
 
-extern int encoding[NACHARS];
-#define CODE_CNT 5
-
 void free_align(edit_script_list_p_t);
 void print_exons(collec_p_t, int);
 void SIM4(hash_env_p_t, seq_p_t, collec_p_t);
